@@ -8,7 +8,7 @@ package Aniki {
     use Aniki::Schema;
     use Aniki::QueryBuilder;
 
-    our $VERSION = '0.02_03';
+    our $VERSION = '0.02_04';
 
     use SQL::Maker::SQLType qw/sql_type/;
     use DBIx::Sunny;
@@ -245,7 +245,7 @@ package Aniki {
             }
         }
 
-        my ($sql, @bind) = $self->query_builder->insert_multi($table_name, $values, $opts);
+        my ($sql, @bind) = $self->query_builder->insert_multi($table_name, \@values, $opts);
         my $sth  = $self->execute($sql, @bind);
         my $rows = $sth->rows;
         $sth->finish;
@@ -370,7 +370,15 @@ package Aniki {
         for my $col (keys %{$args}) {
             # if $args->{$col} is a ref, it is scalar ref or already
             # sql type bined parameter. so ignored.
-            $bind_args{$col} = ref $args->{$col} ? $args->{$col} : sql_type(\$args->{$col}, $table->get_field($col)->sql_data_type);
+            if (ref $args->{$col}) {
+                $bind_args{$col} = $args->{$col};
+            }
+            elsif (my $field = $table->get_field($col)) {
+                $bind_args{$col} = sql_type(\$args->{$col}, $field->sql_data_type);
+            }
+            else {
+                $bind_args{$col} = $args->{$col};
+            }
         }
 
         return \%bind_args;
